BlockHeader

Struct BlockHeader 

pub struct BlockHeader {
    pub version: u32,
    pub prev_blockhash: Hash,
    pub merkle_root: Hash,
    pub time: u32,
    pub bits: u32,
    pub nonce: u32,
}
A block header, which contains all the block’s information except the actual transactions

Fields

version: u32

The protocol version. Should always be 1.

prev_blockhash: Hash

Reference to the previous block in the chain

merkle_root: Hash

The root hash of the merkle tree of transactions in the block

time: u32

The timestamp of the block, as claimed by the miner

bits: u32

The target value below which the blockhash must lie, encoded as a a float (with well-defined rounding, of course)

nonce: u32

The nonce, selected to obtain a low enough blockhash

Implementations

Source

impl BlockHeader

pub fn target(&self) -> Uint256

Computes the target [0, T] that a blockhash must land in to be valid

pub fn compact_target_from_u256(value: &Uint256) -> u32

Computes the target value in float format from Uint256 format.

pub fn difficulty(&self, network: Network) -> u64

Compute the popular “difficulty” measure for mining

pub fn spv_validate(&self, required_target: &Uint256) -> Result<(), Error>

Performs an SPV validation of a block, which confirms that the proof-of-work is correct, but does not verify that the transactions are valid or encoded correctly.

pub fn work(&self) -> Uint256

Returns the total work of the block