pub struct LoneBlockHeader {
pub header: BlockHeader,
pub tx_count: VarInt,
}Expand description
A block header with txcount attached, which is given in the headers
network message.
Fields
header: BlockHeaderThe actual block header
tx_count: VarIntThe number of transactions in the block. This will always be zero
when the LoneBlockHeader is returned as part of a headers message.