pub struct TxOut {
pub value: u64,
pub script_pubkey: Script,
}Expand description
A transaction output, which defines new coins to be created from old ones.
Fields
value: u64The value of the output, in satoshis
script_pubkey: ScriptThe script which must satisfy for the output to be spent