Module address

Module address 

Bitcoin network addresses

This module defines the structures and functions needed to encode network addresses in Bitcoin messages.

Structs

Address
A message which can be sent on the Bitcoin network