RawNetworkMessage

Struct RawNetworkMessage 

pub struct RawNetworkMessage {
    pub magic: u32,
    pub payload: NetworkMessage,
}
A Network message

Fields

magic: u32

Magic bytes to identify the network these messages are meant for

payload: NetworkMessage

The actual message data

Implementations

Source

impl RawNetworkMessage

pub fn cmd(&self) -> &'static str

Return the message command as a static string reference.

This returns "unknown" for NetworkMessage::Unknown, regardless of the actual command in the unknown message. Use the [command] method to get the command for unknown messages.

pub fn command(&self) -> CommandString

Return the CommandString for the message command.