VersionMessage

Struct VersionMessage 

pub struct VersionMessage {
    pub version: u32,
    pub services: u64,
    pub timestamp: i64,
    pub receiver: Address,
    pub sender: Address,
    pub nonce: u64,
    pub user_agent: String,
    pub start_height: i32,
    pub relay: bool,
}
Some simple messages The version message

Fields

version: u32

The P2P network protocol version

services: u64

A bitmask describing the services supported by this node

timestamp: i64

The time at which the version message was sent

receiver: Address

The network address of the peer receiving the message

sender: Address

The network address of the peer sending the message

nonce: u64

A random nonce used to detect loops in the network

user_agent: String

A string describing the peer’s software

start_height: i32

The height of the maximum-work blockchain that the peer is aware of

relay: bool

Whether the receiving peer should relay messages to the sender; used if the sender is bandwidth-limited and would like to support bloom filtering. Defaults to true.

Implementations

Source

impl VersionMessage

pub fn new( services: u64, timestamp: i64, receiver: Address, sender: Address, nonce: u64, user_agent: String, start_height: i32, ) -> VersionMessage

Constructs a new version message