Module self

Module self 

Bitcoin blocks.

A block is a bundle of transactions with a proof-of-work attached, which commits to an earlier block to form the blockchain. This module describes structures and functions needed to describe these blocks and the blockchain.

Structs

Block
Bitcoin block.
BlockDecoder
The decoder for the Block type.
BlockDecoderError
An error consensus decoding a Block.
BlockEncoder
The encoder for the Block type.
BlockHash
A bitcoin block hash.
BlockHashDecoder
The decoder for the BlockHash type.
BlockHashDecoderError
An error consensus decoding a BlockHash.
BlockHashEncoder
The encoder for the BlockHash type.
Header
Bitcoin block header.
HeaderDecoder
The decoder for the Header type.
HeaderEncoder
The encoder for the Header type.
TxMerkleNode
A hash of the Merkle tree branch or root for transactions.
TxMerkleNodeDecoder
The decoder for the TxMerkleNode type.
TxMerkleNodeDecoderError
An error consensus decoding an TxMerkleNode.
TxMerkleNodeEncoder
The encoder for the TxMerkleNode type.
Version
Bitcoin block version number.
VersionDecoder
The decoder for the Version type.
VersionDecoderError
An error consensus decoding an Version.
VersionEncoder
The encoder for the Version type.
WitnessCommitment
A hash corresponding to the witness structure commitment in the coinbase transaction.
WitnessMerkleNode
A hash corresponding to the Merkle tree root for witness data.
WitnessMerkleNodeDecoder
The decoder for the WitnessMerkleNode type.
WitnessMerkleNodeDecoderError
An error consensus decoding an WitnessMerkleNode.
WitnessMerkleNodeEncoder
The encoder for the WitnessMerkleNode type.

Enums

Bip34Error
An error when looking up a BIP34 block height.
HeaderDecoderError
An error consensus decoding a Header.
ValidationError
A block validation error.