pub struct ExtendedPrivKey {
pub network: Network,
pub depth: u8,
pub parent_fingerprint: Fingerprint,
pub child_number: ChildNumber,
pub private_key: PrivateKey,
pub chain_code: ChainCode,
}Expand description
Extended private key
Fields
network: NetworkThe network this key is to be used on
depth: u8How many derivations this key is from the master (which is 0)
parent_fingerprint: FingerprintFingerprint of the parent key (0 for master)
child_number: ChildNumberChild number of the key used to derive from parent (0 for master)
private_key: PrivateKeyPrivate key
chain_code: ChainCodeChain code
Implementations
Sourceimpl ExtendedPrivKey
impl ExtendedPrivKey
Sourcepub fn new_master(
secp: &Secp256k1,
network: Network,
seed: &[u8],
) -> Result<ExtendedPrivKey, Error>
pub fn new_master( secp: &Secp256k1, network: Network, seed: &[u8], ) -> Result<ExtendedPrivKey, Error>
Construct a new master key from a seed value
Sourcepub fn derive_priv<P: AsRef<[ChildNumber]>>(
&self,
secp: &Secp256k1,
path: &P,
) -> Result<ExtendedPrivKey, Error>
pub fn derive_priv<P: AsRef<[ChildNumber]>>( &self, secp: &Secp256k1, path: &P, ) -> Result<ExtendedPrivKey, Error>
Attempts to derive an extended private key from a path.
The path argument can be both of type DerivationPath or Vec<ChildNumber>.
Sourcepub fn ckd_priv(
&self,
secp: &Secp256k1,
i: ChildNumber,
) -> Result<ExtendedPrivKey, Error>
pub fn ckd_priv( &self, secp: &Secp256k1, i: ChildNumber, ) -> Result<ExtendedPrivKey, Error>
Private->Private child key derivation
Sourcepub fn decode(secp: &Secp256k1, data: &[u8]) -> Result<ExtendedPrivKey, Error>
pub fn decode(secp: &Secp256k1, data: &[u8]) -> Result<ExtendedPrivKey, Error>
Decoding extended private key from binary data according to BIP 32
Sourcepub fn identifier(&self, secp: &Secp256k1) -> XpubIdentifier
pub fn identifier(&self, secp: &Secp256k1) -> XpubIdentifier
Returns the HASH160 of the public key belonging to the xpriv
Sourcepub fn fingerprint(&self, secp: &Secp256k1) -> Fingerprint
pub fn fingerprint(&self, secp: &Secp256k1) -> Fingerprint
Returns the first four bytes of the identifier