pub enum Error {
Secp256k1(Error),
Encode(Error),
Network(Error),
SpvBadProofOfWork,
SpvBadTarget,
}Expand description
A general error code, other errors should implement conversions to/from this if appropriate.
Variants
Secp256k1(Error)
secp-related error
Encode(Error)
Encoding error
Network(Error)
Network error
SpvBadProofOfWork
The header hash is not below the target
SpvBadTarget
The target field of a block header did not match the expected difficulty