Module hash

Module hash 

Hash functions

Utility functions related to hashing data, including merkleization

Traits

BitcoinHash
Objects which are referred to by hash
MerkleRoot
Any collection of objects for which a merkle root makes sense to calculate

Functions

bitcoin_merkle_root
Calculates the merkle root of a list of txids hashes directly