pub struct PrivateKey {
pub compressed: bool,
pub network: Network,
pub key: SecretKey,
}Expand description
A Bitcoin ECDSA private key
Fields
compressed: boolWhether this private key should be serialized as compressed
network: NetworkThe network on which this key should be used
key: SecretKeyThe actual ECDSA key
Implementations
Sourceimpl PrivateKey
impl PrivateKey
Sourcepub fn public_key(&self, secp: &Secp256k1) -> PublicKey
pub fn public_key(&self, secp: &Secp256k1) -> PublicKey
Creates a public key from this private key