Network constants
This module provides various constants relating to the Bitcoin network protocol, such as protocol versioning and magic header bytes.
The Network type implements the Decodable and
Encodable traits and encodes the magic bytes of the given
network
Example: encoding a network’s magic bytes
use bitcoin::network::constants::Network;
use bitcoin::consensus::encode::serialize;
let network = Network::Bitcoin;
let bytes = serialize(&network);
assert_eq!(&bytes[..], &[0xF9, 0xBE, 0xB4, 0xD9]);Enums
- Network
- The cryptocurrency to act on
Constants
- PROTOCOL_
VERSION - Version of the protocol as appearing in network message headers
- SERVICES
- Bitfield of services provided by this node
- USER_
AGENT - User agent as it appears in the version message