pub struct PartiallySignedTransaction {
pub global: Global,
pub inputs: Vec<Input>,
pub outputs: Vec<Output>,
}Expand description
A Partially Signed Transaction.
Fields
global: GlobalThe key-value pairs for all global data.
inputs: Vec<Input>The corresponding key-value map for each input in the unsigned transaction.
outputs: Vec<Output>The corresponding key-value map for each output in the unsigned transaction.
Implementations
Sourceimpl PartiallySignedTransaction
impl PartiallySignedTransaction
Sourcepub fn from_unsigned_tx(tx: Transaction) -> Result<Self, Error>
pub fn from_unsigned_tx(tx: Transaction) -> Result<Self, Error>
Create a PartiallySignedTransaction from an unsigned transaction, error if not unsigned
Sourcepub fn extract_tx(self) -> Transaction
pub fn extract_tx(self) -> Transaction
Extract the Transaction from a PartiallySignedTransaction by filling in the available signature information in place.